{% extends "admin/change_form.html" %}
{% load i18n future %}

{% block extrahead %}
{{ block.super }}
<!-- slug field isn't optional for links, so hide the help text -->
<style>.slug .help {display:none;}</style>
{% endblock %}


